@@ -2,7 +2,7 @@ package Kelp::Module::MongoDB;
 use Kelp::Base 'Kelp::Module';
 use MongoDB;
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '1.000';
 
 sub build {
     my ( $self, %args ) = @_;
@@ -14,11 +14,13 @@ sub build {
 
 __END__
 
-=pod
-
 =head1 NAME
 
-  Kelp::Module::MongoDB - Use MongoDB within Kelp
+Kelp::Module::MongoDB - Use MongoDB within Kelp
+
+=head1 DESCRIPTION
+
+L<Kelp::Module::MongoDB> is a L<Kelp> plugin.
 
 =head1 SYNOPSIS
 
@@ -49,17 +51,26 @@ Then ...
     }
 
 
-=head1 REGISTERED METHODS
+
+=head1 METHODS
 
 This module registers only one method into the application: C<mongodb>.
 It is an instance of a L<MongoDB> class.
 
-=head2 AUTHOR
+=head1 AUTHOR
 
-Adam Stokes <adam.stokes@ubuntu.com>
+Adam Stokes E<lt>adamjs@cpan.orgE<gt>
 
-=head2 LICENCE
+=head1 COPYRIGHT
 
-Perl
+Copyright 2013- Adam Stokes
+
+=head1 LICENSE
+
+Licensed under the same terms as Perl.
+
+=head1 SEE ALSO
+
+L<Kelp>.
 
 =cut
